# -*- coding: utf-8 -*-

from __future__ import absolute_import

from cms.test_utils.testcases import CMSTestCase
from django.test import TestCase


class VimeoTestCase(CMSTestCase):

    def setUp(self):
        pass
